sequencetools.partition_sequence_by_ratio_of_lengths
====================================================

.. autofunction:: abjad.tools.sequencetools.partition_sequence_by_ratio_of_lengths.partition_sequence_by_ratio_of_lengths
